pitchtools.chromatic_pitch_number_to_diatonic_pitch_number
==========================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_number_to_diatonic_pitch_number.chromatic_pitch_number_to_diatonic_pitch_number
